==> psitransfer-2.0.1.tgz: package/lang/en.js <==
module.exports = {
  langCode: "en",
  oldBrowserError: "Your browser is too old and does not support this function.",
  dropFilesHere: "Drop your files here",
  noPreviewAvailable: "No preview available",
  preview: "Preview",
  comment: "Comment",
  settings: "Settings",
  retention: "Retention",
  password: "Password",
  required: "required",
  optional: "optional",
  generateRandomPassword: "Generate a random password",
  newUpload: "New upload",
  accessDenied: "Access denied!",
  login: "Login",
  email: "E-Mail",
  clipboard: "Clipboard",
  copyToClipboard: "Copy to clipboard",
  sendViaMail: "Send via E-Mail",
  showQrCode: "Show QR-Code",
  uploadCompleted: "Upload completed",
  downloadLink: "Download Link",
  upload: "upload",
  retry: "retry",
  createNewUploadSession: "Create a new upload session?",
  decrypt: "decrypt",
  files: "Files",
  zipDownload: "Download all files as ZIP (not resumeable)",
  tarGzDownload: "Download all files as tar.gz (not resumeable)",
  oneTimeDownloadExpired: "One-Time Download: File is not available anymore.",
  fileSizeExceed: "File size %% exceeds maximum of %%",
  bucketSizeExceed: "Upload size %% exceeds maximum of %%",
  mailInvalid: "The e-mail address looks faulty",
  mailTo: "Send to",
  mailToPlaceholder: "E-Mail addresses",
  mailFrom: "My E-Mail address",
  mailFromPlaceholder: "E-Mail address",
  mailMessage: "My message",
  mailDownloadNotification: "Notify me when a file hase been downloaded.",
  mailSendBtn: "Send E-Mail",
  mailsSent: "The e-mails have been sent.",
  mailSubjectUploader: "PsiTransfer File-Upload",
  mailSubjectDownloader: "PsiTransfer File-Download",
  mailSubjectFileDownloaded: "File has been downloaded",
  retentions: {
    "one-time": "one time download",
    "3600": "1 Hour",
    "21600": "6 Hours",
    "86400": "1 Day",
    "259200": "3 Days",
    "604800": "1 Week",
    "1209600": "2 Weeks",
    "2419200": "4 Weeks",
    "4838400": "8 Weeks"
  },
}

==> psitransfer-2.2.0.tgz: package/lang/en.js <==
module.exports = {
  langCode: "en",
  oldBrowserError: "Your browser is too old and does not support this function.",
  dropFilesHere: "Drop your files here",
  noPreviewAvailable: "No preview available",
  preview: "Preview",
  comment: "Comment",
  settings: "Settings",
  retention: "Retention",
  password: "Password",
  required: "required",
  optional: "optional",
  generateRandomPassword: "Generate a random password",
  newUpload: "New upload",
  accessDenied: "Access denied!",
  login: "Login",
  email: "E-Mail",
  clipboard: "Clipboard",
  copyToClipboard: "Copy to clipboard",
  sendViaMail: "Send via E-Mail",
  showQrCode: "Show QR-Code",
  uploadCompleted: "Upload completed",
  downloadLink: "Download Link",
  upload: "upload",
  retry: "retry",
  createNewUploadSession: "Create a new upload session?",
  decrypt: "decrypt",
  files: "Files",
  zipDownload: "Download all files as ZIP (not resumeable)",
  tarGzDownload: "Download all files as tar.gz (not resumeable)",
  oneTimeDownloadExpired: "One-Time Download: File is not available anymore.",
  fileSizeExceed: "File size %% exceeds maximum of %%",
  bucketSizeExceed: "Upload size %% exceeds maximum of %%",
  mailInvalid: "The e-mail address looks faulty",
  mailTo: "Send to",
  mailToPlaceholder: "E-Mail addresses",
  mailFrom: "My E-Mail address",
  mailFromPlaceholder: "E-Mail address",
  mailMessage: "My message",
  mailDownloadNotification: "Notify me when a file has been downloaded.",
  mailSendBtn: "Send E-Mail",
  mailsSent: "The e-mails have been sent.",
  mailSubjectUploader: "PsiTransfer File-Upload",
  mailSubjectDownloader: "PsiTransfer File-Download",
  mailSubjectFileDownloaded: "File has been downloaded",
  retentions: {
    "one-time": "one time download",
    "3600": "1 Hour",
    "21600": "6 Hours",
    "86400": "1 Day",
    "259200": "3 Days",
    "604800": "1 Week",
    "1209600": "2 Weeks",
    "2419200": "4 Weeks",
    "4838400": "8 Weeks"
  },
  uploadPassword: "Password for uploading",
}
